# options.py
#
# Project: AutoArchive
# License: GNU GPLv3
#
# Copyright (C) 2003 - 2009 Robert Cernansky
# Copyright (C) 2003 - 2009 HOME software



"""Provides access to options passed to application.
"""



# INCLUDES

from aautils import *
import optparse
import meta



# FUNCTIONS

def processArguments(parser):
    "Processes arguments passed to aa and initializes options instance."

    opts, args = parser.parse_args(values = options)

    # check arguments
    if len(args) < 1:
        parser.error("No archive spec file passed. Please specify an .aa file.")

    if options.level != None and not options.incremental:
        parser.error("There is no point to specify backup level if " + \
                         "incremental backup is not enabled.")

    if options.compresion_level and options.archiver == "tar":
        parser.error("Archiver type 'tar' does not support compresion.")

    if options.compresion_level and options.archiver == "tarlzma":
        printError("warning: Compression level value for tarlzma archive is" +
                   " ignored.")

    arguments.extend(args)



def __initOptionParser():
    "Creates and initializes option parser."

    # define usage and version strings
    usage = "Usage: %prog [options] AA_SPEC..."

    description = "Simple backup utility."

    version = """\
%%prog version %(version)s

%(copyright)s

%(license)s
""" % {"version": meta.VERSION, "copyright": meta.COPYRIGHT,
       "license": meta.LICENSE}

    epilog = """\
AA_SPEC is an archive spec file. It specifies what should be archived and the
archive name. Its standard file name extension is ".aa". For syntax please see
README file. It is possible to specify multiple ".aa" files.
"""

    # create parser
    parser = optparse.OptionParser(usage = usage, version = version,
                                   description = description, epilog = epilog)

    # defaults
    parser.set_defaults(
        verbose = False,
        archiver = "tarbz2",
        incremental = False
        )

    # add options
    parser.add_option("-v", "--verbose",
                      action = "count",
                      help = "Turns on verbose output.")

    choices = ("tar", "targz", "tarbz2", "tarlzma")
    parser.add_option("-a", "--archiver",
                      choices = choices,
                      help = "Specify archiver type. Supported types are: " + \
                          "%(choices)s (default: %%default)." % \
                          {"choices": choices})

    parser.add_option("-i", "--incremental",
                      action = "store_true",
                      help = "Perform incremental backup.")

    parser.add_option("-l", "--level",
                      type = "int",
                      help = "Specify backup level which should be created." + \
                          " Informations about higher levels will be " + \
                          "erased.  If not present, creates next level " + \
                          "in a row.")

    parser.add_option("-c", "--compresion-level",
                      choices = [str(level) for level in range(1, 10)],
                      metavar = "NUM",
                      help = "Compression level. If not specified, default " + \
                          "behaviour of underlying  compression program " + \
                          "will be used.")

    return parser



# MAIN PROGRAM

optionParser = __initOptionParser()

options = optparse.Values(optionParser.defaults)
arguments = []
